==> verttice_ui-0.0.97.tar.gz: lib/src/widgets/files/images/image_viewer.dart <==
import "dart:typed_data";
import "package:collection/collection.dart";
import 'package:verttice_logic/verttice_logic.dart';
import 'package:verttice_ui/src/const/icons.dart';
import "package:flutter/material.dart";
import 'package:verttice_ui/src/widgets/themed_widgets/themed_widgets_index.dart';

import 'image_viewer_full_page.dart';

class ImageViewer extends StatefulWidget {
  final String? url;
  final Uint8List? data;
  final String? asset;
  final double? height;
  ImageViewer({
    Key? key,
    this.url,
    this.data,
    this.asset,
    this.height,
  }) : super(key: key) {
    assert(
      url != null || data != null || asset != null,
      "Must provide url or data or asset",
    );
  }
  @override
  State createState() => _ImageViewerState();
}

class _ImageViewerState extends State<ImageViewer> {
  late String? _url;
  late Uint8List? _data;
  late String? _asset;
  late String _imageID;

  @override
  void initState() {
    super.initState();
    _url = widget.url;
    _data = widget.data;
    _asset = widget.asset;
    _imageID = IDs.l18();
  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  void didUpdateWidget(covariant ImageViewer oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (_url != widget.url ||
        !const DeepCollectionEquality().equals(_data, widget.data) ||
        _asset != widget.asset) {
      _url = widget.url;
      _data = widget.data;
      _asset = widget.asset;
      _imageID = IDs.l18();
    }
  }

  @override
  Widget build(BuildContext context) {
    return SizedBox(
      height: widget.height ?? MediaQuery.of(context).size.height / 2.5,
      child: Material(
        child: InkWell(
          child: Hero(
            tag: _imageID,
            child: Center(
              child: Container(
                decoration: BoxDecoration(
                  color: Colors.blueGrey[700]!.withOpacity(0.5),
                  borderRadius: const BorderRadius.all(
                    Radius.circular(7.0),
                  ),
                ),
                child: Builder(builder: (context) {
                  if (_url != null) {
                    return ClipRRect(
                      borderRadius: BorderRadius.circular(7.0),
                      clipBehavior: Clip.hardEdge,
                      child: Image.network(
                        _url!,
                        fit: BoxFit.cover,
                        errorBuilder: (
                          BuildContext context,
                          Object object,
                          StackTrace? trace,
                        ) {
                          return SizedBox(
                            child: Center(
                              child: ThemedIcons.fileUnknow(
                                iconStyle: IconStyle(
                                  size: 17,
                                ),
                              ),
                            ),
                          );
                        },
                        loadingBuilder: (
                          BuildContext context,
                          Widget child,
                          ImageChunkEvent? loadingProgress,
                        ) {
                          if (loadingProgress == null) {
                            return SizedBox(
                              child: ClipRRect(
                                clipBehavior: Clip.hardEdge,
                                borderRadius: BorderRadius.circular(7.0),
                                child: child,
                              ),
                            );
                          }
                          return SizedBox(
                            child: Center(
                              child: ThemedProgress(
                                progress: loadingProgress.expectedTotalBytes !=
                                        null
                                    ? loadingProgress.cumulativeBytesLoaded /
                                        loadingProgress.expectedTotalBytes!
                                    : null,
                              ),
                            ),
                          );
                        },
                      ),
                    );
                  } else if (_data != null) {
                    return ClipRRect(
                      borderRadius: BorderRadius.circular(7.0),
                      child: Image.memory(
                        _data!,
                        fit: BoxFit.cover,
                        errorBuilder: (
                          BuildContext context,
                          Object object,
                          StackTrace? trace,
                        ) {
                          return SizedBox(
                            child: Center(
                              child: ThemedIcons.fileUnknow(
                                iconStyle: IconStyle(
                                  size: 17,
                                ),
                              ),
                            ),
                          );
                        },
                      ),
                    );
                  }
                  return ClipRRect(
                    borderRadius: BorderRadius.circular(7.0),
                    child: Image.asset(
                      _asset!,
                      fit: BoxFit.cover,
                      errorBuilder: (
                        BuildContext context,
                        Object object,
                        StackTrace? trace,
                      ) {
                        return SizedBox(
                          child: Center(
                            child: ThemedIcons.fileUnknow(
                              iconStyle: IconStyle(
                                size: 17,
                              ),
                            ),
                          ),
                        );
                      },
                    ),
                  );
                }),
              ),
            ),
          ),
          onTap: () {
            Navigator.push(
              context,
              MaterialPageRoute(
                builder: ((context) => ImageViewerFullPage(
                      imageID: _imageID,
                      asset: _asset,
                      data: _data,
                      url: _url,
                    )),
              ),
            );
          },
        ),
      ),
    );
  }
}

==> verttice_ui-0.0.150.tar.gz: lib/src/widgets/files/images/image_viewer.dart <==
// 🎯 Dart imports:
import "dart:typed_data";

// 🐦 Flutter imports:
import "package:flutter/material.dart";

// 📦 Package imports:
import "package:collection/collection.dart";
import 'package:verttice_logic/verttice_logic.dart';

// 🌎 Project imports:
import 'package:verttice_ui/src/const/icons.dart';
import 'package:verttice_ui/src/widgets/themed_widgets/themed_widgets_index.dart';
import 'image_viewer_full_page.dart';

class ImageViewer extends StatefulWidget {
  final String? url;
  final Uint8List? data;
  final String? asset;
  final double? height;
  final double? width;
  ImageViewer({
    Key? key,
    this.url,
    this.data,
    this.asset,
    this.height,
    this.width,
  }) : super(key: key) {
    assert(
      url != null || data != null || asset != null,
      "Must provide url or data or asset",
    );
  }
  @override
  State createState() => _ImageViewerState();
}

class _ImageViewerState extends State<ImageViewer> {
  late String? _url;
  late Uint8List? _data;
  late String? _asset;
  late String _imageID;

  @override
  void initState() {
    super.initState();
    _url = widget.url;
    _data = widget.data;
    _asset = widget.asset;
    _imageID = IDs.l18();
  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  void didUpdateWidget(covariant ImageViewer oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (_url != widget.url ||
        !const DeepCollectionEquality().equals(_data, widget.data) ||
        _asset != widget.asset) {
      _url = widget.url;
      _data = widget.data;
      _asset = widget.asset;
      _imageID = IDs.l18();
    }
  }

  @override
  Widget build(BuildContext context) {
    return SizedBox(
      height: widget.height,
      width: widget.width,
      child: Material(
        child: InkWell(
          child: Hero(
            tag: _imageID,
            child: Center(
              child: Container(
                decoration: BoxDecoration(
                  color: Colors.blueGrey[700]!.withOpacity(0.5),
                  borderRadius: const BorderRadius.all(
                    Radius.circular(7.0),
                  ),
                ),
                child: Builder(builder: (context) {
                  if (_url != null) {
                    return ClipRRect(
                      borderRadius: BorderRadius.circular(7.0),
                      clipBehavior: Clip.hardEdge,
                      child: Image.network(
                        _url!,
                        height: widget.height,
                        width: widget.width,
                        fit: BoxFit.cover,
                        errorBuilder: (
                          BuildContext context,
                          Object object,
                          StackTrace? trace,
                        ) {
                          return SizedBox(
                            height: widget.height,
                            width: widget.width,
                            child: Center(
                              child: ThemedIcons.unknown(
                                iconStyle: IconStyle(
                                  size: 17,
                                ),
                              ),
                            ),
                          );
                        },
                        loadingBuilder: (
                          BuildContext context,
                          Widget child,
                          ImageChunkEvent? loadingProgress,
                        ) {
                          if (loadingProgress == null) {
                            return SizedBox(
                              child: ClipRRect(
                                clipBehavior: Clip.hardEdge,
                                borderRadius: BorderRadius.circular(7.0),
                                child: child,
                              ),
                            );
                          }
                          return SizedBox(
                            height: widget.height,
                            width: widget.width,
                            child: Center(
                              child: ThemedProgress(
                                progress: loadingProgress.expectedTotalBytes !=
                                        null
                                    ? loadingProgress.cumulativeBytesLoaded /
                                        loadingProgress.expectedTotalBytes!
                                    : null,
                              ),
                            ),
                          );
                        },
                      ),
                    );
                  } else if (_data != null) {
                    return ClipRRect(
                      borderRadius: BorderRadius.circular(7.0),
                      child: Image.memory(
                        _data!,
                        height: widget.height,
                        width: widget.width,
                        fit: BoxFit.cover,
                        errorBuilder: (
                          BuildContext context,
                          Object object,
                          StackTrace? trace,
                        ) {
                          return SizedBox(
                            height: widget.height,
                            width: widget.width,
                            child: Center(
                              child: ThemedIcons.unknown(
                                iconStyle: IconStyle(
                                  size: 17,
                                ),
                              ),
                            ),
                          );
                        },
                      ),
                    );
                  }
                  return ClipRRect(
                    borderRadius: BorderRadius.circular(7.0),
                    child: Image.asset(
                      _asset!,
                      height: widget.height,
                      width: widget.width,
                      fit: BoxFit.cover,
                      errorBuilder: (
                        BuildContext context,
                        Object object,
                        StackTrace? trace,
                      ) {
                        return SizedBox(
                          height: widget.height,
                          width: widget.width,
                          child: Center(
                            child: ThemedIcons.unknown(
                              iconStyle: IconStyle(
                                size: 17,
                              ),
                            ),
                          ),
                        );
                      },
                    ),
                  );
                }),
              ),
            ),
          ),
          onTap: () {
            Navigator.push(
              context,
              MaterialPageRoute(
                builder: ((context) => ImageViewerFullPage(
                      imageID: _imageID,
                      asset: _asset,
                      data: _data,
                      url: _url,
                    )),
              ),
            );
          },
        ),
      ),
    );
  }
}
